MigrationRegistry class

Migration registry for the client-side database.

Constructors

MigrationRegistry()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

migrations List<MigrationVersionSql>
Ordered list of all client-side database migrations. New migrations are always appended at the end.
final
versions List<String>
List of all client-side database migration versions.
no setter