BaseHlc class

Base class for HLC timestamps.

This class is used to represent the base HLC timestamp, which will be extended with the node ID (in its canonical or normalized form).

Implemented types
Available extensions

Constructors

BaseHlc({required DateTime hlcDatetime, required int hlcCounter})
BaseHlc.fromJson(Map<String, dynamic> jsonSerialization)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
hlcCounter int
The counter component of the HLC timestamp.
getter/setter pair
hlcDatetime DateTime
The datetime component of the HLC timestamp.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({DateTime? hlcDatetime, int? hlcCounter}) BaseHlc
Returns a shallow copy of this BaseHlc with some or all fields replaced by the given arguments.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toHlcForNode(UuidValue nodeId) Hlc

Available on BaseHlc, provided by the BaseHlcToHlc extension

Converts the BaseHlc to an Hlc with the given nodeId.
toJson() Map<String, dynamic>
Returns a serialized JSON structure of the model which also includes fields used by the database.
override
toJsonForProtocol() Map<String, dynamic>
Returns a JSON structure of the model, optimized for Protocol communication.
override
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited