CrdtDataAttemptedValueRepository class

Properties

attachRow CrdtDataAttemptedValueAttachRowRepository
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

count(DatabaseSession session, {WhereExpressionBuilder<CrdtDataAttemptedValueTable>? where, int? limit, Transaction? transaction}) Future<int>
Counts the number of rows matching the where expression. If omitted, will return the count of all rows in the table.
delete(DatabaseSession session, List<CrdtDataAttemptedValue> rows, {OrderByBuilder<CrdtDataAttemptedValueTable>? orderBy, OrderByListBuilder<CrdtDataAttemptedValueTable>? orderByList, Transaction? transaction, bool noReturn = false}) Future<List<CrdtDataAttemptedValue>>
Deletes all CrdtDataAttemptedValues in the list and returns the deleted rows.
deleteRow(DatabaseSession session, CrdtDataAttemptedValue row, {Transaction? transaction}) Future<CrdtDataAttemptedValue>
Deletes a single CrdtDataAttemptedValue.
deleteWhere(DatabaseSession session, {required WhereExpressionBuilder<CrdtDataAttemptedValueTable> where, OrderByBuilder<CrdtDataAttemptedValueTable>? orderBy, OrderByListBuilder<CrdtDataAttemptedValueTable>? orderByList, Transaction? transaction, bool noReturn = false}) Future<List<CrdtDataAttemptedValue>>
Deletes all rows matching the where expression.
find(DatabaseSession session, {WhereExpressionBuilder<CrdtDataAttemptedValueTable>? where, int? limit, int? offset, OrderByBuilder<CrdtDataAttemptedValueTable>? orderBy, OrderByListBuilder<CrdtDataAttemptedValueTable>? orderByList, Transaction? transaction, CrdtDataAttemptedValueInclude? include, LockMode? lockMode, LockBehavior? lockBehavior}) Future<List<CrdtDataAttemptedValue>>
Returns a list of CrdtDataAttemptedValues matching the given query parameters.
findById(DatabaseSession session, int id, {Transaction? transaction, CrdtDataAttemptedValueInclude? include, LockMode? lockMode, LockBehavior? lockBehavior}) Future<CrdtDataAttemptedValue?>
Finds a single CrdtDataAttemptedValue by its id or null if no such row exists.
findFirstRow(DatabaseSession session, {WhereExpressionBuilder<CrdtDataAttemptedValueTable>? where, int? offset, OrderByBuilder<CrdtDataAttemptedValueTable>? orderBy, OrderByListBuilder<CrdtDataAttemptedValueTable>? orderByList, Transaction? transaction, CrdtDataAttemptedValueInclude? include, LockMode? lockMode, LockBehavior? lockBehavior}) Future<CrdtDataAttemptedValue?>
Returns the first matching CrdtDataAttemptedValue matching the given query parameters.
insert(DatabaseSession session, List<CrdtDataAttemptedValue> rows, {Transaction? transaction, bool ignoreConflicts = false, bool noReturn = false}) Future<List<CrdtDataAttemptedValue>>
Inserts all CrdtDataAttemptedValues in the list and returns the inserted rows.
insertRow(DatabaseSession session, CrdtDataAttemptedValue row, {Transaction? transaction}) Future<CrdtDataAttemptedValue>
Inserts a single CrdtDataAttemptedValue and returns the inserted row.
lockRows(DatabaseSession session, {required WhereExpressionBuilder<CrdtDataAttemptedValueTable> where, required LockMode lockMode, required Transaction transaction, LockBehavior lockBehavior = _isd.LockBehavior.wait}) Future<void>
Acquires row-level locks on CrdtDataAttemptedValue rows matching the where expression.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
update(DatabaseSession session, List<CrdtDataAttemptedValue> rows, {ColumnSelections<CrdtDataAttemptedValueTable>? columns, Transaction? transaction, bool noReturn = false}) Future<List<CrdtDataAttemptedValue>>
Updates all CrdtDataAttemptedValues in the list and returns the updated rows. If columns is provided, only those columns will be updated. Defaults to all columns. This is an atomic operation, meaning that if one of the rows fails to update, none of the rows will be updated.
updateById(DatabaseSession session, int id, {required ColumnValueListBuilder<CrdtDataAttemptedValueUpdateTable> columnValues, Transaction? transaction}) Future<CrdtDataAttemptedValue?>
Updates a single CrdtDataAttemptedValue by its id with the specified columnValues. Returns the updated row or null if no row with the given id exists.
updateRow(DatabaseSession session, CrdtDataAttemptedValue row, {ColumnSelections<CrdtDataAttemptedValueTable>? columns, Transaction? transaction}) Future<CrdtDataAttemptedValue>
Updates a single CrdtDataAttemptedValue. The row needs to have its id set. Optionally, a list of columns can be provided to only update those columns. Defaults to all columns.
updateWhere(DatabaseSession session, {required ColumnValueListBuilder<CrdtDataAttemptedValueUpdateTable> columnValues, required WhereExpressionBuilder<CrdtDataAttemptedValueTable> where, int? limit, int? offset, OrderByBuilder<CrdtDataAttemptedValueTable>? orderBy, OrderByListBuilder<CrdtDataAttemptedValueTable>? orderByList, Transaction? transaction, bool noReturn = false}) Future<List<CrdtDataAttemptedValue>>
Updates all CrdtDataAttemptedValues matching the where expression with the specified columnValues. Returns the list of updated rows.
upsert(DatabaseSession session, List<CrdtDataAttemptedValue> rows, {required ColumnSelections<CrdtDataAttemptedValueTable> conflictColumns, ColumnSelections<CrdtDataAttemptedValueTable>? updateColumns, WhereExpressionBuilder<CrdtDataAttemptedValueTable>? updateWhere, Transaction? transaction, bool noReturn = false}) Future<List<CrdtDataAttemptedValue>>
Upserts all CrdtDataAttemptedValues in the list and returns the resulting rows.
upsertRow(DatabaseSession session, CrdtDataAttemptedValue row, {required ColumnSelections<CrdtDataAttemptedValueTable> conflictColumns, ColumnSelections<CrdtDataAttemptedValueTable>? updateColumns, WhereExpressionBuilder<CrdtDataAttemptedValueTable>? updateWhere, Transaction? transaction}) Future<CrdtDataAttemptedValue?>
Upserts a single CrdtDataAttemptedValue and returns the resulting row.

Operators

operator ==(Object other) bool
The equality operator.
inherited