CrdtDataField class abstract

CRDT data table.

This table stores only the HLC timestamp for a field. During merge, if the other HLC is greater, the actual data must be fetched from the table itself.

Inheritance
Implemented types
Available extensions

Constructors

CrdtDataField({int? id, required DateTime hlcDatetime, required int hlcCounter, required int rowId, CrdtDataRow? row, required int columnId, CrdtSchemaColumn? column, required int nodeId, CrdtNode? node, CrdtDataAttemptedValue? attemptedValue})
factory
CrdtDataField.fromJson(Map<String, dynamic> jsonSerialization)
factory

Properties

attemptedValue CrdtDataAttemptedValue?
Authored value retained while a projector materializes a different domain value for this field.
getter/setter pair
column CrdtSchemaColumn?
Column that the field belongs to.
getter/setter pair
columnId int
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
hlc Hlc

Available on CrdtDataField, provided by the CrdtDataFieldExtension extension

The HLC represented by this field.
no setter
hlcCounter int
The counter component of the HLC timestamp.
getter/setter pairinherited
hlcDatetime DateTime
The datetime component of the HLC timestamp.
getter/setter pairinherited
id int?
The id column of the row. Can be null if this row is not yet stored in the database.
getter/setter pair
node CrdtNode?
The node that updated the field.
getter/setter pair
nodeId int
getter/setter pair
row CrdtDataRow?
Row that the field belongs to.
getter/setter pair
rowId int
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
table → Table<int?>
The table that this row belongs to.
no setter

Methods

copyWith({int? id, DateTime? hlcDatetime, int? hlcCounter, int? rowId, CrdtDataRow? row, int? columnId, CrdtSchemaColumn? column, int? nodeId, CrdtNode? node, CrdtDataAttemptedValue? attemptedValue}) CrdtDataField
Returns a shallow copy of this CrdtDataField with some or all fields replaced by the given arguments.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toHlcForNode(UuidValue nodeId) Hlc

Available on BaseHlc, provided by the BaseHlcToHlc extension

Converts the BaseHlc to an Hlc with the given nodeId.
toJson() Map<String, dynamic>
Returns a serialized JSON structure of the model which also includes fields used by the database.
override
toJsonForProtocol() Map<String, dynamic>
Returns a JSON structure of the model, optimized for Protocol communication.
override
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

t CrdtDataFieldTable
final

Static Methods

include({CrdtDataRowInclude? row, CrdtSchemaColumnInclude? column, CrdtNodeInclude? node, CrdtDataAttemptedValueInclude? attemptedValue}) CrdtDataFieldInclude
includeList({WhereExpressionBuilder<CrdtDataFieldTable>? where, int? limit, int? offset, OrderByBuilder<CrdtDataFieldTable>? orderBy, OrderByListBuilder<CrdtDataFieldTable>? orderByList, CrdtDataFieldInclude? include}) CrdtDataFieldIncludeList

Constants

db → const CrdtDataFieldRepository