CrdtMergeUpdate class abstract
A remote field update to merge.
- Inheritance
-
- Object
- BaseHlc
- CrdtMergeChange
- CrdtMergeUpdate
- Implemented types
- Available extensions
Constructors
- CrdtMergeUpdate({required DateTime hlcDatetime, required int hlcCounter, required UuidValue uuidSpaceId, required String tableName, required UuidValue uuidRowId, required UuidValue uuidNodeId, required String columnName, required dynamic value})
-
factory
-
CrdtMergeUpdate.fromJson(Map<
String, dynamic> jsonSerialization) -
factory
Properties
- columnName ↔ String
-
The updated database column name.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- hlc → Hlc
-
Available on CrdtMergeChange, provided by the CrdtMergeChangeExtension extension
The HLC represented by this change.no setter - hlcCounter ↔ int
-
The counter component of the HLC timestamp.
getter/setter pairinherited
- hlcDatetime ↔ DateTime
-
The datetime component of the HLC timestamp.
getter/setter pairinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- tableName ↔ String
-
The table receiving the change.
getter/setter pairinherited
- uuidNodeId ↔ UuidValue
-
The remote node that produced the change.
getter/setter pairinherited
- uuidRowId ↔ UuidValue
-
The domain row identifier receiving the change.
getter/setter pairinherited
- uuidSpaceId ↔ UuidValue
-
The space this change belongs to.
getter/setter pairinherited
- value ↔ dynamic
-
The serialized new value for the column.
getter/setter pair
Methods
-
copyWith(
{DateTime? hlcDatetime, int? hlcCounter, UuidValue? uuidSpaceId, String? tableName, UuidValue? uuidRowId, UuidValue? uuidNodeId, String? columnName, dynamic value}) → CrdtMergeUpdate -
Returns a shallow copy of this CrdtMergeUpdate
with some or all fields replaced by the given arguments.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toHlcForNode(
UuidValue nodeId) → Hlc -
Available on BaseHlc, provided by the BaseHlcToHlc extension
Converts the BaseHlc to an Hlc with the givennodeId. -
toJson(
) → Map< String, dynamic> -
Returns a serialized JSON structure of the model which also includes
fields used by the database.
override
-
toJsonForProtocol(
) → Map< String, dynamic> -
Returns a JSON structure of the model, optimized for Protocol communication.
override
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited