CrdtNodeTable class
Properties
columns
→ List <Column >
List of Column used by the table.
no setter
hasColumnMapping
→ bool
Cached flag indicating whether any columns have explicit column names
that differ from their field names. Computed lazily on first access.
late final inherited
hashCode
→ int
The hash code for this object.
no setter inherited
id
↔ ColumnComparable<int ? >
The database id.
late final inherited
lastHlc
↔ ColumnStructured<Hlc >
Last HLC generated by the local replica when this row is the current node.
late final
managedColumns
→ List <Column >
List of Column that are managed by this table.
This is mostly used to exclude columns created by implicit relations.
no setter inherited
queryPrefix
→ String
Query prefix for Columns of the table.
no setter inherited
quotedTableName
→ String
tableName quoted for the current dialect. Prefer it over tableName in
raw SQL, since dialects quote schemas differently.
no setter inherited
runtimeType
→ Type
A representation of the runtime type of the object.
no setter inherited
schema
→ String ?
Schema part of tableName, or null when the name is unqualified.
late final inherited
tableName
→ String
Name of the table as used in the database, optionally qualified as
schema.table.
final inherited
tableRelation
→ TableRelation?
Table relation for Columns of the table.
final inherited
unqualifiedTableName
→ String
tableName with the schema removed.
late final inherited
updateTable
↔ CrdtNodeUpdateTable
late final
uuidNodeId
↔ ColumnUuid
Stable unique identifier for the replica/database install.
late final
Methods
getRelationTable (String relationField )
→ Table?
Returns TableColumnRelation for the given relationField. If no relation
exists, returns null. The return must be dynamic to allow for relations
with different id types.
inherited
noSuchMethod (Invocation invocation )
→ dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString ()
→ String
A string representation of this object.
inherited
serverpod_offline_sync_client 0.0.6