CrdtSchemaTable class abstract

CRDT schema tables table.

Implemented types

Constructors

CrdtSchemaTable({int? id, required String name})
factory
CrdtSchemaTable.fromJson(Map<String, dynamic> jsonSerialization)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
id int?
The id column of the row. Can be null if this row is not yet stored in the database.
getter/setter pair
name String
Name of the synchronized table.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
table → Table<int?>
The table that this row belongs to.
no setter

Methods

copyWith({int? id, String? name}) CrdtSchemaTable
Returns a shallow copy of this CrdtSchemaTable with some or all fields replaced by the given arguments.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Returns a serialized JSON structure of the model which also includes fields used by the database.
override
toJsonForProtocol() Map<String, dynamic>
Returns a JSON structure of the model, optimized for Protocol communication.
override
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

t CrdtSchemaTableTable
final

Static Methods

include() CrdtSchemaTableInclude
includeList({WhereExpressionBuilder<CrdtSchemaTableTable>? where, int? limit, int? offset, OrderByBuilder<CrdtSchemaTableTable>? orderBy, OrderByListBuilder<CrdtSchemaTableTable>? orderByList, CrdtSchemaTableInclude? include}) CrdtSchemaTableIncludeList

Constants

db → const CrdtSchemaTableRepository