CrdtScopeRepository class

Properties

attach CrdtScopeAttachRepository
final
attachRow CrdtScopeAttachRowRepository
final
detachRow CrdtScopeDetachRowRepository
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

count(DatabaseSession session, {WhereExpressionBuilder<CrdtScopeTable>? where, int? limit, Transaction? transaction}) Future<int>
Counts the number of rows matching the where expression. If omitted, will return the count of all rows in the table.
delete(DatabaseSession session, List<CrdtScope> rows, {OrderByBuilder<CrdtScopeTable>? orderBy, OrderByListBuilder<CrdtScopeTable>? orderByList, Transaction? transaction, bool noReturn = false}) Future<List<CrdtScope>>
Deletes all CrdtScopes in the list and returns the deleted rows.
deleteRow(DatabaseSession session, CrdtScope row, {Transaction? transaction}) Future<CrdtScope>
Deletes a single CrdtScope.
deleteWhere(DatabaseSession session, {required WhereExpressionBuilder<CrdtScopeTable> where, OrderByBuilder<CrdtScopeTable>? orderBy, OrderByListBuilder<CrdtScopeTable>? orderByList, Transaction? transaction, bool noReturn = false}) Future<List<CrdtScope>>
Deletes all rows matching the where expression.
find(DatabaseSession session, {WhereExpressionBuilder<CrdtScopeTable>? where, int? limit, int? offset, OrderByBuilder<CrdtScopeTable>? orderBy, OrderByListBuilder<CrdtScopeTable>? orderByList, Transaction? transaction, CrdtScopeInclude? include, LockMode? lockMode, LockBehavior? lockBehavior}) Future<List<CrdtScope>>
Returns a list of CrdtScopes matching the given query parameters.
findById(DatabaseSession session, int id, {Transaction? transaction, CrdtScopeInclude? include, LockMode? lockMode, LockBehavior? lockBehavior}) Future<CrdtScope?>
Finds a single CrdtScope by its id or null if no such row exists.
findFirstRow(DatabaseSession session, {WhereExpressionBuilder<CrdtScopeTable>? where, int? offset, OrderByBuilder<CrdtScopeTable>? orderBy, OrderByListBuilder<CrdtScopeTable>? orderByList, Transaction? transaction, CrdtScopeInclude? include, LockMode? lockMode, LockBehavior? lockBehavior}) Future<CrdtScope?>
Returns the first matching CrdtScope matching the given query parameters.
insert(DatabaseSession session, List<CrdtScope> rows, {Transaction? transaction, bool ignoreConflicts = false, bool noReturn = false}) Future<List<CrdtScope>>
Inserts all CrdtScopes in the list and returns the inserted rows.
insertRow(DatabaseSession session, CrdtScope row, {Transaction? transaction}) Future<CrdtScope>
Inserts a single CrdtScope and returns the inserted row.
lockRows(DatabaseSession session, {required WhereExpressionBuilder<CrdtScopeTable> where, required LockMode lockMode, required Transaction transaction, LockBehavior lockBehavior = _isd.LockBehavior.wait}) Future<void>
Acquires row-level locks on CrdtScope rows matching the where expression.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
update(DatabaseSession session, List<CrdtScope> rows, {ColumnSelections<CrdtScopeTable>? columns, Transaction? transaction, bool noReturn = false}) Future<List<CrdtScope>>
Updates all CrdtScopes in the list and returns the updated rows. If columns is provided, only those columns will be updated. Defaults to all columns. This is an atomic operation, meaning that if one of the rows fails to update, none of the rows will be updated.
updateById(DatabaseSession session, int id, {required ColumnValueListBuilder<CrdtScopeUpdateTable> columnValues, Transaction? transaction}) Future<CrdtScope?>
Updates a single CrdtScope by its id with the specified columnValues. Returns the updated row or null if no row with the given id exists.
updateRow(DatabaseSession session, CrdtScope row, {ColumnSelections<CrdtScopeTable>? columns, Transaction? transaction}) Future<CrdtScope>
Updates a single CrdtScope. The row needs to have its id set. Optionally, a list of columns can be provided to only update those columns. Defaults to all columns.
updateWhere(DatabaseSession session, {required ColumnValueListBuilder<CrdtScopeUpdateTable> columnValues, required WhereExpressionBuilder<CrdtScopeTable> where, int? limit, int? offset, OrderByBuilder<CrdtScopeTable>? orderBy, OrderByListBuilder<CrdtScopeTable>? orderByList, Transaction? transaction, bool noReturn = false}) Future<List<CrdtScope>>
Updates all CrdtScopes matching the where expression with the specified columnValues. Returns the list of updated rows.
upsert(DatabaseSession session, List<CrdtScope> rows, {required ColumnSelections<CrdtScopeTable> conflictColumns, ColumnSelections<CrdtScopeTable>? updateColumns, WhereExpressionBuilder<CrdtScopeTable>? updateWhere, Transaction? transaction, bool noReturn = false}) Future<List<CrdtScope>>
Upserts all CrdtScopes in the list and returns the resulting rows.
upsertRow(DatabaseSession session, CrdtScope row, {required ColumnSelections<CrdtScopeTable> conflictColumns, ColumnSelections<CrdtScopeTable>? updateColumns, WhereExpressionBuilder<CrdtScopeTable>? updateWhere, Transaction? transaction}) Future<CrdtScope?>
Upserts a single CrdtScope and returns the resulting row.

Operators

operator ==(Object other) bool
The equality operator.
inherited