CrdtSyncClose class abstract

Marks a graceful end of a one-shot sync session.

Both peers send CrdtSyncClose after merging the final batch in a one-shot session so each side can shut down without closing the transport early.

Inheritance
Implemented types

Constructors

CrdtSyncClose()
factory
CrdtSyncClose.fromJson(Map<String, dynamic> jsonSerialization)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith() CrdtSyncClose
Returns a shallow copy of this CrdtSyncClose with some or all fields replaced by the given arguments.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Returns a serialized JSON structure of the model which also includes fields used by the database.
override
toJsonForProtocol() Map<String, dynamic>
Returns a JSON structure of the model, optimized for Protocol communication.
override
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited