CrdtSyncSession class

A running continuous CRDT sync session.

Properties

done Future<void>
Completes when the sync session ends normally or after cancel.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

cancel() Future<void>
Stops the sync session and closes the transport. This method is idempotent and can be called multiple times.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited