DuplicateNodeException class

Exception thrown when a duplicate node is detected.

Implemented types

Constructors

DuplicateNodeException(UuidValue nodeId)
Creates a new instance of DuplicateNodeException.

Properties

hashCode int
The hash code for this object.
no setterinherited
nodeId UuidValue
The node ID that is duplicated.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited