OfflineSyncClient class

High-level client sync helpers built on top of a CRDT stream transport.

Constructors

OfflineSyncClient(OfflineSyncTransport transport)
Creates a OfflineSyncClient for the provided transport.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
syncContinuously(DatabaseSession session, {OfflineSyncOnMergeSuccess? onMergeSuccess}) OfflineSyncSubscription
Keeps synchronizing session with the remote peer until cancelled through OfflineSyncSubscription.cancel or the remote stream closes.
syncOnce(DatabaseSession session, {OfflineSyncOnMergeSuccess? onMergeSuccess}) Future<void>
Pushes local pending changes for session to the remote peer once.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited