logWarning property
Optional function to log a warning during the execution of a query.
Implementation
@override
LogWarningFunction? get logWarning => null;
Optional function to log a warning during the execution of a query.
@override
LogWarningFunction? get logWarning => null;