OfflineSyncIntegrityViolationException class final
Thrown when sync observes terminal CRDT metadata/domain-row inconsistency.
- Inheritance
-
- Object
- OfflineSyncException
- OfflineSyncIntegrityViolationException
Constructors
- OfflineSyncIntegrityViolationException(OfflineSyncIntegrityViolation violation)
-
Creates a OfflineSyncIntegrityViolationException.
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- violation → OfflineSyncIntegrityViolation
-
The integrity violation that caused sync to stop.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited