OfflineSyncMergeChunk class abstract

A chunk of merge changes carried inside a framed sync batch.

Inheritance
Implemented types

Constructors

OfflineSyncMergeChunk({required List<CrdtMergeChange> changes})
factory
OfflineSyncMergeChunk.fromJson(Map<String, dynamic> jsonSerialization)
factory

Properties

changes List<CrdtMergeChange>
The merge changes to apply.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({List<CrdtMergeChange>? changes}) OfflineSyncMergeChunk
Returns a shallow copy of this OfflineSyncMergeChunk with some or all fields replaced by the given arguments.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Returns a serialized JSON structure of the model which also includes fields used by the database.
override
toJsonForProtocol() Map<String, dynamic>
Returns a JSON structure of the model, optimized for Protocol communication.
override
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited