OfflineSyncSpaceGrant class abstract

A single space a peer announces in a OfflineSyncSpaceSet.

Carries the space UUID and the authoritative role the receiving user holds in it. The personal space is announced with OfflineSyncSpaceRole.readWrite.

Implemented types

Constructors

OfflineSyncSpaceGrant({required UuidValue uuidSpaceId, required OfflineSyncSpaceRole role})
factory
OfflineSyncSpaceGrant.fromJson(Map<String, dynamic> jsonSerialization)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
role OfflineSyncSpaceRole
Authoritative CRDT access role of the receiving user in this space.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
uuidSpaceId UuidValue
Space UUID being announced.
getter/setter pair

Methods

copyWith({UuidValue? uuidSpaceId, OfflineSyncSpaceRole? role}) OfflineSyncSpaceGrant
Returns a shallow copy of this OfflineSyncSpaceGrant with some or all fields replaced by the given arguments.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Returns a serialized JSON structure of the model which also includes fields used by the database.
override
toJsonForProtocol() Map<String, dynamic>
Returns a JSON structure of the model, optimized for Protocol communication.
override
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited