OfflineSyncSpaceRepository class
Methods
-
count(DatabaseSession session, {WhereExpressionBuilder<OfflineSyncSpaceTable>? where, int? limit, Transaction? transaction})
→ Future<int>
-
Counts the number of rows matching the
where expression. If omitted,
will return the count of all rows in the table.
-
delete(DatabaseSession session, List<OfflineSyncSpace> rows, {OrderByBuilder<OfflineSyncSpaceTable>? orderBy, OrderByListBuilder<OfflineSyncSpaceTable>? orderByList, Transaction? transaction, bool noReturn = false})
→ Future<List<OfflineSyncSpace>>
-
Deletes all OfflineSyncSpaces in the list and returns the deleted rows.
-
deleteRow(DatabaseSession session, OfflineSyncSpace row, {Transaction? transaction})
→ Future<OfflineSyncSpace>
-
Deletes a single OfflineSyncSpace.
-
deleteWhere(DatabaseSession session, {required WhereExpressionBuilder<OfflineSyncSpaceTable> where, OrderByBuilder<OfflineSyncSpaceTable>? orderBy, OrderByListBuilder<OfflineSyncSpaceTable>? orderByList, Transaction? transaction, bool noReturn = false})
→ Future<List<OfflineSyncSpace>>
-
Deletes all rows matching the
where expression.
-
find(DatabaseSession session, {WhereExpressionBuilder<OfflineSyncSpaceTable>? where, int? limit, int? offset, OrderByBuilder<OfflineSyncSpaceTable>? orderBy, OrderByListBuilder<OfflineSyncSpaceTable>? orderByList, Transaction? transaction, OfflineSyncSpaceInclude? include, LockMode? lockMode, LockBehavior? lockBehavior})
→ Future<List<OfflineSyncSpace>>
-
Returns a list of OfflineSyncSpaces matching the given query parameters.
-
findById(DatabaseSession session, int id, {Transaction? transaction, OfflineSyncSpaceInclude? include, LockMode? lockMode, LockBehavior? lockBehavior})
→ Future<OfflineSyncSpace?>
-
Finds a single OfflineSyncSpace by its
id or null if no such row exists.
-
findFirstRow(DatabaseSession session, {WhereExpressionBuilder<OfflineSyncSpaceTable>? where, int? offset, OrderByBuilder<OfflineSyncSpaceTable>? orderBy, OrderByListBuilder<OfflineSyncSpaceTable>? orderByList, Transaction? transaction, OfflineSyncSpaceInclude? include, LockMode? lockMode, LockBehavior? lockBehavior})
→ Future<OfflineSyncSpace?>
-
Returns the first matching OfflineSyncSpace matching the given query parameters.
-
insert(DatabaseSession session, List<OfflineSyncSpace> rows, {Transaction? transaction, bool ignoreConflicts = false, bool noReturn = false})
→ Future<List<OfflineSyncSpace>>
-
Inserts all OfflineSyncSpaces in the list and returns the inserted rows.
-
insertRow(DatabaseSession session, OfflineSyncSpace row, {Transaction? transaction})
→ Future<OfflineSyncSpace>
-
Inserts a single OfflineSyncSpace and returns the inserted row.
-
lockRows(DatabaseSession session, {required WhereExpressionBuilder<OfflineSyncSpaceTable> where, required LockMode lockMode, required Transaction transaction, LockBehavior lockBehavior = _isd.LockBehavior.wait})
→ Future<void>
-
Acquires row-level locks on OfflineSyncSpace rows matching the
where expression.
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toString()
→ String
-
A string representation of this object.
inherited
-
update(DatabaseSession session, List<OfflineSyncSpace> rows, {ColumnSelections<OfflineSyncSpaceTable>? columns, Transaction? transaction, bool noReturn = false})
→ Future<List<OfflineSyncSpace>>
-
Updates all OfflineSyncSpaces in the list and returns the updated rows. If
columns is provided, only those columns will be updated. Defaults to
all columns.
This is an atomic operation, meaning that if one of the rows fails to
update, none of the rows will be updated.
-
updateById(DatabaseSession session, int id, {required ColumnValueListBuilder<OfflineSyncSpaceUpdateTable> columnValues, Transaction? transaction})
→ Future<OfflineSyncSpace?>
-
Updates a single OfflineSyncSpace by its
id with the specified columnValues.
Returns the updated row or null if no row with the given id exists.
-
updateRow(DatabaseSession session, OfflineSyncSpace row, {ColumnSelections<OfflineSyncSpaceTable>? columns, Transaction? transaction})
→ Future<OfflineSyncSpace>
-
Updates a single OfflineSyncSpace. The row needs to have its id set.
Optionally, a list of
columns can be provided to only update those
columns. Defaults to all columns.
-
updateWhere(DatabaseSession session, {required ColumnValueListBuilder<OfflineSyncSpaceUpdateTable> columnValues, required WhereExpressionBuilder<OfflineSyncSpaceTable> where, int? limit, int? offset, OrderByBuilder<OfflineSyncSpaceTable>? orderBy, OrderByListBuilder<OfflineSyncSpaceTable>? orderByList, Transaction? transaction, bool noReturn = false})
→ Future<List<OfflineSyncSpace>>
-
Updates all OfflineSyncSpaces matching the
where expression with the specified columnValues.
Returns the list of updated rows.
-
upsert(DatabaseSession session, List<OfflineSyncSpace> rows, {required ColumnSelections<OfflineSyncSpaceTable> conflictColumns, ColumnSelections<OfflineSyncSpaceTable>? updateColumns, WhereExpressionBuilder<OfflineSyncSpaceTable>? updateWhere, Transaction? transaction, bool noReturn = false})
→ Future<List<OfflineSyncSpace>>
-
Upserts all OfflineSyncSpaces in the list and returns the resulting rows.
-
upsertRow(DatabaseSession session, OfflineSyncSpace row, {required ColumnSelections<OfflineSyncSpaceTable> conflictColumns, ColumnSelections<OfflineSyncSpaceTable>? updateColumns, WhereExpressionBuilder<OfflineSyncSpaceTable>? updateWhere, Transaction? transaction})
→ Future<OfflineSyncSpace?>
-
Upserts a single OfflineSyncSpace and returns the resulting row.