OfflineSyncSpaceSet class abstract
Authoritative or informational space set exchanged at the start of a cycle.
The server sends the authoritative membership set (with roles). The client sends an empty set; the server never widens access from follower-reported state.
- Inheritance
-
- Object
- OfflineSyncStreamEvent
- OfflineSyncSpaceSet
- Implemented types
Constructors
-
OfflineSyncSpaceSet({required List<
OfflineSyncSpaceGrant> spaces}) -
factory
-
OfflineSyncSpaceSet.fromJson(Map<
String, dynamic> jsonSerialization) -
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
spaces
↔ List<
OfflineSyncSpaceGrant> -
Spaces this peer reports for the next sync cycle, each with the receiving
user's authoritative role.
getter/setter pair
Methods
-
copyWith(
{List< OfflineSyncSpaceGrant> ? spaces}) → OfflineSyncSpaceSet -
Returns a shallow copy of this OfflineSyncSpaceSet
with some or all fields replaced by the given arguments.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
Returns a serialized JSON structure of the model which also includes
fields used by the database.
override
-
toJsonForProtocol(
) → Map< String, dynamic> -
Returns a JSON structure of the model, optimized for Protocol communication.
override
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited