spaces property
Spaces this peer reports for the next sync cycle, each with the receiving user's authoritative role.
Implementation
List<_icw2tu00.OfflineSyncSpaceGrant> spaces;
Spaces this peer reports for the next sync cycle, each with the receiving user's authoritative role.
List<_icw2tu00.OfflineSyncSpaceGrant> spaces;