OfflineSyncUnexpectedEventException<T extends OfflineSyncStreamEvent> class final

Thrown when the inbound sync stream delivers an event of the wrong type.

Inheritance

Constructors

OfflineSyncUnexpectedEventException({required String expected, required OfflineSyncStreamEvent received})
Creates a OfflineSyncUnexpectedEventException.
const

Properties

expected String
A description of the expected event type or types.
final
hashCode int
The hash code for this object.
no setterinherited
received OfflineSyncStreamEvent
The event that was received instead.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited