ServerpodClientUnknownHttpException class

Thrown if the server responded with an HTTP status code that the client has no dedicated exception for.

Inheritance

Constructors

ServerpodClientUnknownHttpException(String data, int statusCode)
Creates an Unknown Http Exception from the response data and the statusCode the server responded with.

Properties

hashCode int
The hash code for this object.
no setterinherited
message String
Error message sent from the server.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
statusCode int
Http status code associated with the error.
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited