serverpod_offline_sync_client
library
Classes
-
AuthenticationKeyManager
-
Manages keys for authentication with the server.
-
BadRequestMessage
-
A message sent when a bad request is received.
-
BaseHlc
-
Base class for HLC timestamps.
-
Bit
-
Represents a binary vector, where each element is either
true or false.
-
Caller
-
-
ClientAuthKeyProvider
-
Provides the authentication key for the client.
-
CloseMethodStreamCommand
-
A message sent over a websocket connection to close a websocket stream of
data to an endpoint method.
-
ConnectivityMonitor
-
Keeps track of internet connectivity and notifies its listeners when the
internet connection is either lost or regained. For most use cases, use
the concrete FlutterConnectivityMonitor class in the serverpod_flutter
package.
-
CrdtDataAttemptedValue
-
Authored field value retained while the domain column holds a projection.
-
CrdtDataAttemptedValueAttachRowRepository
-
-
CrdtDataAttemptedValueInclude
-
-
CrdtDataAttemptedValueIncludeList
-
-
CrdtDataAttemptedValueRepository
-
-
CrdtDataAttemptedValueTable
-
-
CrdtDataAttemptedValueUpdateTable
-
-
CrdtDatabase
-
Database proxy that runs insert/update/delete ORM operations inside a
transaction to record each change in the CRDT tables.
-
CrdtDatabaseContext
-
Process-level CRDT database metadata shared by ephemeral database wrappers.
-
CrdtDatabaseSession
-
Wraps a
DatabaseSession to provide a CrdtDatabase as DatabaseSession.db.
-
CrdtDataDeleted
-
CRDT visibility generation table.
-
CrdtDataDeletedAttachRowRepository
-
-
CrdtDataDeletedInclude
-
-
CrdtDataDeletedIncludeList
-
-
CrdtDataDeletedRepository
-
-
CrdtDataDeletedTable
-
-
CrdtDataDeletedUpdateTable
-
-
CrdtDataField
-
CRDT data table.
-
CrdtDataFieldAttachRowRepository
-
-
CrdtDataFieldInclude
-
-
CrdtDataFieldIncludeList
-
-
CrdtDataFieldRepository
-
-
CrdtDataFieldTable
-
-
CrdtDataFieldUpdateTable
-
-
CrdtDataRow
-
CRDT data rows table.
-
CrdtDataRowAttachRepository
-
-
CrdtDataRowAttachRowRepository
-
-
CrdtDataRowInclude
-
-
CrdtDataRowIncludeList
-
-
CrdtDataRowRepository
-
-
CrdtDataRowTable
-
-
CrdtDataRowUpdateTable
-
-
CrdtMergeChange
-
A remote CRDT change to merge.
-
CrdtMergeDelete
-
A remote visibility CLFlag update to merge.
-
CrdtMergeInsert
-
A remote row insertion to merge.
-
CrdtMergeUpdate
-
A remote field update to merge.
-
CrdtMutationRecorder
-
Persists additional CRDT rows after a mutating ORM operation completes.
-
CrdtNode
-
CRDT nodes table.
-
CrdtNodeInclude
-
-
CrdtNodeIncludeList
-
-
CrdtNodeRepository
-
-
CrdtNodeTable
-
-
CrdtNodeUpdateTable
-
-
CrdtSchemaColumn
-
CRDT schema columns table.
-
CrdtSchemaColumnAttachRowRepository
-
-
CrdtSchemaColumnInclude
-
-
CrdtSchemaColumnIncludeList
-
-
CrdtSchemaColumnRepository
-
-
CrdtSchemaColumnTable
-
-
CrdtSchemaColumnUpdateTable
-
-
CrdtSchemaRegistry
-
Manages the CRDT schema for a database.
-
CrdtSchemaTable
-
CRDT schema tables table.
-
CrdtSchemaTableInclude
-
-
CrdtSchemaTableIncludeList
-
-
CrdtSchemaTableRepository
-
-
CrdtSchemaTableTable
-
-
CrdtSchemaTableUpdateTable
-
-
CrdtScope
-
CRDT scopes table.
-
CrdtScopeAttachRepository
-
-
CrdtScopeAttachRowRepository
-
-
CrdtScopeDetachRowRepository
-
-
CrdtScopeGrant
-
A single scope a peer announces in a CrdtSyncScopeSet.
-
CrdtScopeInclude
-
-
CrdtScopeIncludeList
-
-
CrdtScopeManager
-
A manager for CrdtScope instances.
-
CrdtScopeMember
-
Authorization membership for shared CRDT scopes.
-
CrdtScopeMemberAttachRowRepository
-
-
CrdtScopeMemberInclude
-
-
CrdtScopeMemberIncludeList
-
-
CrdtScopeMemberRepository
-
-
CrdtScopeMembership
-
Resolves shared-scope membership from the
crdt_scope_members table.
-
CrdtScopeMemberTable
-
-
CrdtScopeMemberUpdateTable
-
-
CrdtScopeNode
-
A CRDT node's participation and checkpoint state within one scope.
-
CrdtScopeNodeAttachRowRepository
-
-
CrdtScopeNodeInclude
-
-
CrdtScopeNodeIncludeList
-
-
CrdtScopeNodeRepository
-
-
CrdtScopeNodeTable
-
-
CrdtScopeNodeUpdateTable
-
-
CrdtScopeRepository
-
-
CrdtScopeTable
-
-
CrdtScopeUpdateTable
-
-
CrdtSync
-
The shared CRDT synchronization logic used by both client and server nodes.
-
CrdtSyncClient
-
High-level client sync helpers built on top of a CRDT stream transport.
-
CrdtSyncClose
-
Marks a graceful end of a one-shot sync session.
-
CrdtSyncConnect
-
Session handshake sent once by each peer before any scope work.
-
CrdtSyncCycleBatch
-
One sync cycle's inbound frames.
-
CrdtSyncEndOfBatch
-
Marks the end of a framed sync batch.
-
CrdtSyncIdleTimeout
-
Marks a timeout of an idle sync session.
-
CrdtSyncIntegrityViolation
-
Durable record of a terminal CRDT sync integrity violation.
-
CrdtSyncIntegrityViolationInclude
-
-
CrdtSyncIntegrityViolationIncludeList
-
-
CrdtSyncIntegrityViolationRepository
-
-
CrdtSyncIntegrityViolationTable
-
-
CrdtSyncIntegrityViolationUpdateTable
-
-
CrdtSyncMergeChunk
-
A chunk of merge changes carried inside a framed sync batch.
-
CrdtSyncScopeSet
-
Authoritative or informational scope set exchanged at the start of a cycle.
-
CrdtSyncSession
-
A running continuous CRDT sync session.
-
CrdtSyncSinceHlc
-
Per-scope checkpoint sent by each peer before the first visit to a scope.
-
CrdtSyncStreamEvent
-
A CRDT sync event sent over a bidirectional stream.
-
CrossTabLock
-
A mutual-exclusion lock shared across cooperating execution contexts that
hold the same credentials, such as browser tabs of one origin.
-
DeepCollectionEquality
-
Deep equality on collections.
-
EndpointCaller
-
Super class for all classes that can call a server endpoint.
-
EndpointCrdtSync
Endpoint
-
Endpoint for CRDT-based offline-first synchronization.
-
EndpointRef
-
This class connects endpoints on the server with the client, it also
hooks up streams with the endpoint. Overridden by generated code.
-
FileUploader
-
The file uploader uploads files to Serverpod's cloud storage. On the server
you can setup a custom storage service, such as S3 or Google Cloud. To
directly upload a file, you first need to retrieve an upload description
from your server. After the file is uploaded, make sure to notify the server
by calling
verifyUpload on the current Session object.
-
Geography
-
Abstract base class for all PostGIS geography types.
-
GeographyGeometryCollection
-
Represents a PostGIS GeometryCollection — a heterogeneous collection of
Geography values (points, line strings, polygons).
-
GeographyLineString
-
Represents a geographic line string (sequence of points) for use with PostGIS.
-
GeographyPoint
-
Represents a geographic point with longitude, latitude, and spatial
reference system identifier (SRID) for use with PostGIS.
-
GeographyPolygon
-
Represents a geographic polygon (exterior ring + optional holes) for PostGIS.
-
HalfVector
-
Represents a vector of half-precision float values.
-
Hlc
-
A Hybrid Logical Clock implementation that supports both ISO 8601 and Unix
timestamp formats. The datetime component has millisecond precision and is
always stored in UTC.
-
HlcManager
-
A manager for Hlc instances that is used to generate unique timestamps
for CRDT operations.
-
MethodCallContext
-
Context for a method call.
-
MethodStreamMessage
-
A message sent to a method stream.
-
MethodStreamSerializableException
-
A serializable exception sent over a method stream.
-
ModuleEndpointCaller
-
This class is used to connect modules with the client. Overridden by
generated code.
-
MutexRefresherClientAuthKeyProvider
-
A RefresherClientAuthKeyProvider decorator that adds a mutex lock to
prevent concurrent refresh calls. Actual auth header getter and refresh
logic is delegated to the
_delegate provider.
-
OpenMethodStreamCommand
-
A message sent over a websocket connection to open a websocket stream of
data to an endpoint method.
-
OpenMethodStreamResponse
-
A message sent over a websocket connection to respond to an
OpenMethodStreamCommand.
-
PingCommand
-
A message sent over a websocket connection to check if the connection is
still alive. The other end should respond with a PongCommand.
-
PongCommand
-
A response to a PingCommand.
-
Protocol
-
-
ProtocolSerialization
-
The ProtocolSerialization defines a toJsonForProtocol method which makes it
possible to limit what fields are serialized when communicating over the
protocol.
-
RefresherClientAuthKeyProvider
-
Provides the authentication key for the client, with a method to refresh it.
-
SerializableModel
-
The SerializableModel is the base interface for all serializable objects in
Serverpod, except primitives.
-
SerializationManager
-
The SerializationManager is responsible for creating objects from a
serialization, but also for serializing objects. This class is typically
extended by generated code.
-
ServerpodClientRequestDelegate
-
Defines the interface of the delegate that performs the actual request to the server
and returns the response data.
The delegate is used by ServerpodClientShared to perform the actual request.
It's overridden in different versions depending on if the dart:io library
is available.
-
ServerpodClientShared
-
Superclass with shared methods for handling communication with the server.
Is typically overridden by generated code to provide implementations of methods for calling the server.
-
SparseVector
-
Represents a sparse vector that stores only non-zero elements.
-
Uuid
-
uuid for Dart
Author: Yulian Kuncheff
Released under MIT License.
-
UuidValue
-
-
Vector
-
Represents a vector of double values.
-
WebSocketMessage
-
Base class for messages sent over a WebSocket connection.
-
WebSocketMessageInfo
-
Interface of WebSocketMessage subclasses that have endpoint,
method and connection id info.
Constants
-
autoSerializedTypes
→ const List<String>
-
All datatypes that are serialized by default.
Used internally in Serverpod code generation.
-
basicAuthSchemeName
→ const String
-
The name of the default Serverpod scheme for HTTP "authorization" headers.
Note, the scheme name is case-insensitive and should be compared in a case-insensitive manner.
-
bearerAuthSchemeName
→ const String
-
The name of the Bearer scheme for HTTP "authorization" headers.
Note, the scheme name is case-insensitive and should be compared in a case-insensitive manner.
-
extensionSerializedTypes
→ const List<String>
-
All datatypes that has extensions to support serialization.
Used internally in Serverpod code generation.
-
hasCloneExtensionTypes
→ const List<String>
-
List of types that has a clone method extension and therefore can be
copied by calling clone().
-
immutable
→ const Immutable
-
Annotation on an immutable class.
-
useResult
→ const UseResult
-
Annotation on function or property whose value must not be ignored.
-
webAuthModeCookie
→ const String
-
The webAuthModeHeaderName value that selects cookie-based web auth.
-
webAuthModeCookieTransport
→ const String
-
The webAuthModeHeaderName value for cookie transport without
authentication: cookies are still carried and may be set (sign-in, JWT
refresh), but the main auth cookie must not authenticate the call. Sent by
cookie-mode clients for
@unauthenticatedClientCall methods.
-
The request header a web client sets to ask the server to issue the auth
token as an
HttpOnly cookie (in Set-Cookie).
-
The request header a cookie-mode web client sets to declare the
browser-visible base path of the server: the path component of the client's
host, e.g. /api behind a prefix-stripping reverse proxy, or /.
Functions
-
getType<T>()
→ Type
-
Get the type provided as an generic. Useful for getting a nullable type.
-
Returns true if the provided value is a valid HTTP "authorization" header value
(which includes starting with an authentication scheme name).
-
Returns true if the provided value is a Serverpod-wrapped auth key.
-
Returns true if the provided value is a Bearer auth header value.
-
Returns the auth key from an auth value that has potentially been wrapped.
This operation is the inverse of wrapAsBasicAuthHeaderValue and
wrapAsBearerAuthHeaderValue. If null is provided, null is returned.
-
Returns a value that is compliant with the HTTP auth header format
by encoding and wrapping the provided auth key as a Basic auth value.
-
Returns a value that is compliant with the HTTP auth header format
by wrapping the provided token as a Bearer auth value.
Unlike Basic auth, Bearer tokens are not Base64 encoded as they are
expected to already be in the correct format.