CrdtDataDeletedReason enum
Why a synced user tombstone changed row visibility.
- Inheritance
- Implemented types
- Available extensions
Values
- userInsert → const CrdtDataDeletedReason
- userReinsert → const CrdtDataDeletedReason
- userDelete → const CrdtDataDeletedReason
- userCascadeDelete → const CrdtDataDeletedReason
- uniqueLoser → const CrdtDataDeletedReason
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- isSynced → bool
-
Available on CrdtDataDeletedReason, provided by the CrdtDataDeletedReasonExtension extension
Whether this tombstone reason is synced across replicas. All reasons that start with 'user' are synced.no setter - name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → int -
Returns a serialized JSON structure of the model which also includes
fields used by the database.
override
-
toString(
) → String -
A string representation of this object.
override
-
toVisibility(
{required bool isDeleted}) → CrdtDataRowVisibility -
Available on CrdtDataDeletedReason, provided by the CrdtDataDeletedReasonExtension extension
The row visibility that corresponds to this tombstone reason.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
fromJson(
int index) → CrdtDataDeletedReason
Constants
-
values
→ const List<
CrdtDataDeletedReason> - A constant List of the values in this enum, in order of their declaration.