CrdtDataRowUpdateTable class
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- table → CrdtDataRowTable
-
The table instance that this update table operates on.
finalinherited
Methods
-
hlcCounter(
int value) → ColumnValue< int, int> -
hlcDatetime(
DateTime value) → ColumnValue< DateTime, DateTime> -
nodeId(
int value) → ColumnValue< int, int> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
spaceId(
int value) → ColumnValue< int, int> -
tblId(
int value) → ColumnValue< int, int> -
toString(
) → String -
A string representation of this object.
inherited
-
uuidRowId(
UuidValue value) → ColumnValue< UuidValue, UuidValue> -
visibility(
CrdtDataRowVisibility value) → ColumnValue< CrdtDataRowVisibility, CrdtDataRowVisibility>
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited