CrdtMergeChange class sealed
A remote CRDT change to merge.
- Inheritance
- Implemented types
- Available extensions
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- hlc → Hlc
-
Available on CrdtMergeChange, provided by the CrdtMergeChangeExtension extension
The HLC represented by this change.no setter - hlcCounter ↔ int
-
The counter component of the HLC timestamp.
getter/setter pairinherited
- hlcDatetime ↔ DateTime
-
The datetime component of the HLC timestamp.
getter/setter pairinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- tableName ↔ String
-
The table receiving the change.
getter/setter pair
- uuidNodeId ↔ UuidValue
-
The remote node that produced the change.
getter/setter pair
- uuidRowId ↔ UuidValue
-
The domain row identifier receiving the change.
getter/setter pair
- uuidSpaceId ↔ UuidValue
-
The space this change belongs to.
getter/setter pair
Methods
-
copyWith(
{DateTime? hlcDatetime, int? hlcCounter, UuidValue? uuidSpaceId, String? tableName, UuidValue? uuidRowId, UuidValue? uuidNodeId}) → CrdtMergeChange -
Returns a shallow copy of this CrdtMergeChange
with some or all fields replaced by the given arguments.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toHlcForNode(
UuidValue nodeId) → Hlc -
Available on BaseHlc, provided by the BaseHlcToHlc extension
Converts the BaseHlc to an Hlc with the givennodeId. -
toJson(
) → Map< String, dynamic> -
Returns a serialized JSON structure of the model which also includes
fields used by the database.
inherited
-
toJsonForProtocol(
) → Map< String, dynamic> -
Returns a JSON structure of the model, optimized for Protocol communication.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited