CrdtScopeNode class abstract
A CRDT node's participation and checkpoint state within one scope.
- Implemented types
Constructors
- CrdtScopeNode({int? id, required int scopeId, CrdtScope? scope, required int nodeId, CrdtNode? node, Hlc? lastReceivedHlc})
-
factory
-
CrdtScopeNode.fromJson(Map<
String, dynamic> jsonSerialization) -
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- id ↔ int?
-
The id column of the row. Can be null if this row is not yet stored in
the database.
getter/setter pair
- lastReceivedHlc ↔ Hlc?
-
Latest HLC from this node acknowledged for this scope.
getter/setter pair
- node ↔ CrdtNode?
-
Stable replica identity participating in the scope.
getter/setter pair
- nodeId ↔ int
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- scope ↔ CrdtScope?
-
Scope this participation row belongs to.
getter/setter pair
- scopeId ↔ int
-
getter/setter pair
-
table
→ Table<
int?> -
The table that this row belongs to.
no setter
Methods
-
copyWith(
{int? id, int? scopeId, CrdtScope? scope, int? nodeId, CrdtNode? node, Hlc? lastReceivedHlc}) → CrdtScopeNode - Returns a shallow copy of this CrdtScopeNode with some or all fields replaced by the given arguments.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
Returns a serialized JSON structure of the model which also includes
fields used by the database.
override
-
toJsonForProtocol(
) → Map< String, dynamic> -
Returns a JSON structure of the model, optimized for Protocol communication.
override
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- t → CrdtScopeNodeTable
-
final
Static Methods
-
include(
{CrdtScopeInclude? scope, CrdtNodeInclude? node}) → CrdtScopeNodeInclude -
includeList(
{WhereExpressionBuilder< CrdtScopeNodeTable> ? where, int? limit, int? offset, OrderByBuilder<CrdtScopeNodeTable> ? orderBy, OrderByListBuilder<CrdtScopeNodeTable> ? orderByList, CrdtScopeNodeInclude? include}) → CrdtScopeNodeIncludeList
Constants
- db → const CrdtScopeNodeRepository