CrdtSyncSession class
A running continuous CRDT sync session.
Properties
Methods
-
cancel(
) → Future< void> - Stops the sync session and closes the transport. This method is idempotent and can be called multiple times.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited