EndpointOfflineSync class Endpoint
Endpoint for CRDT-based offline-first synchronization.
- Inheritance
-
- Object
- EndpointRef
- EndpointOfflineSync
Constructors
- EndpointOfflineSync(EndpointCaller caller)
Properties
- caller → EndpointCaller
-
Holds a reference to the caller class.
finalinherited
- client ↔ ServerpodClientShared
-
Reference to the client.
latefinalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- name → String
-
The name of the endpoint this reference is connected to.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
sync(
{required Stream< OfflineSyncStreamEvent> changes, required bool once}) → Stream<OfflineSyncStreamEvent> - Opens a bidirectional CRDT sync session with the authenticated client.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited