OfflineSyncCycleBatch class
One sync cycle's inbound frames.
Constructors
Properties
-
changes
→ List<
CrdtMergeChange> -
The peer's merge changes for this cycle.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- isEmpty → bool
-
Whether the peer sent nothing this cycle (it was idle).
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
sinceHlcs
→ Map<
UuidValue, OfflineSyncSinceHlc> -
The peer's resume vectors, keyed by space.
final
- spaceSet ↔ OfflineSyncSpaceSet?
-
The peer's space announcement for this cycle, if it sent one.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited