OfflineSyncDatabaseSession class
Wraps a DatabaseSession to provide a OfflineSyncDatabase as DatabaseSession.db.
- Available extensions
Constructors
-
OfflineSyncDatabaseSession(Database db, {required List<
Table> syncTables, OfflineSyncDatabaseContext? context, int syncBatchSize = OfflineSyncEngine.defaultSyncBatchSize, Duration continuousSyncInterval = OfflineSyncEngine.defaultContinuousSyncInterval, UuidValue? persistentUserId}) - Creates a OfflineSyncDatabaseSession instance.
-
OfflineSyncDatabaseSession.wraps(DatabaseSession session, {required List<
Table> syncTables, OfflineSyncDatabaseContext? context, int syncBatchSize = OfflineSyncEngine.defaultSyncBatchSize, Duration continuousSyncInterval = OfflineSyncEngine.defaultContinuousSyncInterval, UuidValue? persistentUserId}) -
Creates a OfflineSyncDatabaseSession instance that wraps a
DatabaseSession.factory
Properties
- db → OfflineSyncDatabase
-
The database to access.
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- logQuery → LogQueryFunction?
-
Optional function to log a query.
no setter
- logWarning → LogWarningFunction?
-
Optional function to log a warning during the execution of a query.
no setter
- offlineSyncDb → OfflineSyncDatabase
-
Available on DatabaseSession, provided by the OfflineSyncDatabaseAccess extension
Returns the wrapped OfflineSyncDatabase for this session.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- transaction ↔ Transaction?
-
Optional transaction to use for all database queries.
getter/setter pair
Methods
-
close(
) → Future< void> - Closes the underlying client database.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited